@@ -22,7 +22,11 @@
 
 #include "gda-data-model-import.h"
 #include <unistd.h>
-#include <sys/mman.h>
+#ifndef G_OS_WIN32
+  #include <sys/mman.h>
+#else
+  #include <windows.h>
+#endif
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <fcntl.h>
@@ -44,6 +48,7 @@
 #include <libgda/gda-parameter-list.h>
 #include <libgda/gda-dict.h>
 #include <libgda/gda-dict-type.h>
+#include <libgda/gda-data-model-private.h> /* For gda_data_model_add_data_from_xml_node() */
 
 #include <libxml/xmlreader.h>
 
@@ -145,9 +150,9 @@ static void                 gda_data_model_import_data_model_init (GdaDataModelC
 static gint                 gda_data_model_import_get_n_rows      (GdaDataModel *model);
 static gint                 gda_data_model_import_get_n_columns   (GdaDataModel *model);
 static GdaColumn           *gda_data_model_import_describe_column (GdaDataModel *model, gint col);
-static guint                gda_data_model_import_get_access_flags(GdaDataModel *model);
+static GdaDataModelAccessFlags gda_data_model_import_get_access_flags(GdaDataModel *model);
 static const GValue      *gda_data_model_import_get_value_at    (GdaDataModel *model, gint col, gint row);
-static guint                gda_data_model_import_get_attributes_at (GdaDataModel *model, gint col, gint row);
+static GdaValueAttribute    gda_data_model_import_get_attributes_at (GdaDataModel *model, gint col, gint row);
 static GdaDataModelIter    *gda_data_model_impor_create_iter      (GdaDataModel *model);
 static gboolean             gda_data_model_import_iter_next       (GdaDataModel *model, GdaDataModelIter *iter); 
 static gboolean             gda_data_model_import_iter_prev       (GdaDataModel *model, GdaDataModelIter *iter);
@@ -314,15 +319,20 @@ gda_data_model_import_dispose (GObject *object)
 
 		/* data access mem free */
 		if (model->priv->is_mapped) {
+			if (model->priv->src.mapped.start) {
+#ifndef G_OS_WIN32
+				munmap (model->priv->src.mapped.start, model->priv->src.mapped.length);
+#else
+				UnmapViewOfFile (model->priv->src.mapped.start);
+#endif
+				model->priv->src.mapped.start = NULL;
+			}
+
 			g_free (model->priv->src.mapped.filename);
 			if (model->priv->src.mapped.fd >= 0) {
 				close (model->priv->src.mapped.fd);
 				model->priv->src.mapped.fd = -1;
 			}
-			if (model->priv->src.mapped.start) {
-				munmap (model->priv->src.mapped.start, model->priv->src.mapped.length);
-				model->priv->src.mapped.start = NULL;
-			}
 		}
 		else {
 			g_free (model->priv->src.string);
@@ -476,7 +486,7 @@ gda_data_model_import_set_property (GObject *object,
 			model->priv->src.mapped.fd = open (model->priv->src.mapped.filename, O_RDONLY);
 			if (model->priv->src.mapped.fd < 0) {
 				/* error */
-				add_error (model, sys_errlist [errno]);
+				add_error (model, strerror(errno));
 				return;
 			}
 			else {
@@ -485,19 +495,36 @@ gda_data_model_import_set_property (GObject *object,
 
 				if (fstat (model->priv->src.mapped.fd, &_stat) < 0) {
 					/* error */
-					add_error (model, sys_errlist [errno]);
+					add_error (model, strerror(errno));
 					return;
 				}
 				model->priv->src.mapped.length = _stat.st_size;
+#ifndef G_OS_WIN32
 				model->priv->src.mapped.start = mmap (NULL, model->priv->src.mapped.length,
 								      PROT_READ, MAP_PRIVATE, 
 								      model->priv->src.mapped.fd, 0);
 				if (model->priv->src.mapped.start == MAP_FAILED) {
 					/* error */
-					add_error (model, sys_errlist [errno]);
+					add_error (model, strerror(errno));
 					model->priv->src.mapped.start = NULL;
 					return;
 				}
+#else
+				HANDLE view = CreateFileMapping((HANDLE)model->priv->src.mapped.fd, 
+								NULL, PAGE_READONLY|SEC_COMMIT, 0,0 , NULL);
+				if (!view) {
+					/* error */
+					add_error (model, sys_errlist [errno]);
+					return;
+				}
+				model->priv->src.mapped.start = MapViewOfFile(view, FILE_MAP_READ, 0, 0, 
+									      model->priv->src.mapped.length);
+				if (!model->priv->src.mapped.start) {
+					/* error */
+					add_error (model, sys_errlist [errno]);
+					return;
+				}
+#endif
 				model->priv->data_start = model->priv->src.mapped.start;
 				model->priv->data_length = model->priv->src.mapped.length;
 			}
@@ -626,7 +653,7 @@ gda_data_model_import_get_property (GObject *object,
 /**
  * gda_data_model_import_new_file
  * @filename: the file to import data from
- * @random_access: TRUE if a random acces will be required
+ * @random_access: TRUE if random access will be required
  * @options: list of options for the export
  *
  * Creates a new #GdaDataModel object which contains the data stored within the @filename file.
@@ -1286,7 +1313,7 @@ init_xml_import (GdaDataModelImport *model)
 			return;
 
 		name = xmlTextReaderConstName (reader);
-		if (strcmp (name, "gda_array")) {
+		if (strcmp ((gchar*)name, "gda_array")) {
 			/* error */
 			gchar *str;
 
@@ -1298,18 +1325,18 @@ init_xml_import (GdaDataModelImport *model)
 		}
 		node = xmlTextReaderCurrentNode (reader);
 		
-		prop = xmlGetProp (node, "id");
+		prop = (gchar*)xmlGetProp (node, (xmlChar*)"id");
 		if (prop) {
 			gda_object_set_id (GDA_OBJECT (model), prop);
 			xmlFree (prop);
 		}
-		prop = xmlGetProp (node, "name");
+		prop = (gchar*)xmlGetProp (node, (xmlChar*)"name");
 		if (prop) {
 			gda_object_set_name (GDA_OBJECT (model), prop);
 			xmlFree (prop);
 		}
 
-		prop = xmlGetProp (node, "descr");
+		prop = (gchar*)xmlGetProp (node, (xmlChar*)"descr");
 		if (prop) {
 			gda_object_set_description (GDA_OBJECT (model), prop);
 			xmlFree (prop);
@@ -1318,22 +1345,22 @@ init_xml_import (GdaDataModelImport *model)
 		/* compute fields */
 		ret = xml_fetch_next_xml_node (reader);
 		name = (ret > 0) ? xmlTextReaderConstName (reader) : NULL;
-		while (name && !strcmp (name, "gda_array_field")) {
+		while (name && !strcmp ((char*)name, "gda_array_field")) {
 			XmlColumnSpec *spec;
 			gchar *str;
 
 			spec = g_new0 (XmlColumnSpec, 1);
 			fields = g_slist_append (fields, spec);
 			
-			spec->id = xmlTextReaderGetAttribute (reader, "id");
-			spec->name = xmlTextReaderGetAttribute (reader, "name");
-			spec->title = xmlTextReaderGetAttribute (reader, "title");
+			spec->id = xmlTextReaderGetAttribute (reader, (xmlChar*)"id");
+			spec->name = xmlTextReaderGetAttribute (reader, (xmlChar*)"name");
+			spec->title = xmlTextReaderGetAttribute (reader, (xmlChar*)"title");
 			if (!spec->title && spec->name)
-				spec->title = g_strdup (spec->name);
+				spec->title = xmlStrdup (spec->name);
 			
-			spec->caption = xmlTextReaderGetAttribute (reader, "caption");
-			spec->dbms_type = xmlTextReaderGetAttribute (reader, "dbms_type");
-			str = xmlTextReaderGetAttribute (reader, "gdatype");
+			spec->caption = xmlTextReaderGetAttribute (reader, (xmlChar*)"caption");
+			spec->dbms_type = xmlTextReaderGetAttribute (reader, (xmlChar*)"dbms_type");
+			str = (gchar*)xmlTextReaderGetAttribute (reader, (xmlChar*)"gdatype");
 			if (str) {
 				spec->gdatype = gda_g_type_from_string (str);
 				xmlFree (str);
@@ -1345,39 +1372,39 @@ init_xml_import (GdaDataModelImport *model)
 				model->priv->extract.xml.reader = NULL;
 				return;
 			}
-			str = xmlTextReaderGetAttribute (reader, "size");
+			str = (gchar*)xmlTextReaderGetAttribute (reader, (xmlChar*)"size");
 			if (str) {
 				spec->size = atoi (str);
 				xmlFree (str);
 			}
-			str = xmlTextReaderGetAttribute (reader, "scale");
+			str = (gchar*)xmlTextReaderGetAttribute (reader, (xmlChar*)"scale");
 			if (str) {
 				spec->scale = atoi (str);
 				xmlFree (str);
 			}
-			str = xmlTextReaderGetAttribute (reader, "pkey");
+			str = (gchar*)xmlTextReaderGetAttribute (reader, (xmlChar*)"pkey");
 			if (str) {
 				spec->pkey = ((*str == 't') || (*str == 'T')) ? TRUE : FALSE;
 				xmlFree (str);
 			}
-			str = xmlTextReaderGetAttribute (reader, "unique");
+			str = (gchar*)xmlTextReaderGetAttribute (reader, (xmlChar*)"unique");
 			if (str) {
 				spec->unique = ((*str == 't') || (*str == 'T')) ? TRUE : FALSE;
 				xmlFree (str);
 			}
-			str = xmlTextReaderGetAttribute (reader, "nullok");
+			str = (gchar*)xmlTextReaderGetAttribute (reader, (xmlChar*)"nullok");
 			spec->nullok = TRUE;
 			if (str) {
 				spec->nullok = ((*str == 't') || (*str == 'T')) ? TRUE : FALSE;
 				xmlFree (str);
 			}
-			str = xmlTextReaderGetAttribute (reader, "auto_increment");
+			str = (gchar*)xmlTextReaderGetAttribute (reader, (xmlChar*)"auto_increment");
 			if (str) {
 				spec->autoinc = ((*str == 't') || (*str == 'T')) ? TRUE : FALSE;
 				xmlFree (str);
 			}
-			spec->table = xmlTextReaderGetAttribute (reader, "table");
-			spec->ref = xmlTextReaderGetAttribute (reader, "ref");
+			spec->table = xmlTextReaderGetAttribute (reader, (xmlChar*)"table");
+			spec->ref = xmlTextReaderGetAttribute (reader, (xmlChar*)"ref");
 			
 			nbfields ++;
 
@@ -1403,18 +1430,18 @@ init_xml_import (GdaDataModelImport *model)
 			column = gda_column_new ();
 			model->priv->columns = g_slist_append (model->priv->columns, column);
 			g_object_set (G_OBJECT (column), "id", spec->id, NULL);
-			gda_column_set_title (column, spec->title);
-			gda_column_set_name (column, spec->name);
+			gda_column_set_title (column, (gchar*)spec->title);
+			gda_column_set_name (column, (gchar*)spec->name);
 			gda_column_set_defined_size (column, spec->size);
-			gda_column_set_caption (column, spec->caption);
-			gda_column_set_dbms_type (column, spec->dbms_type);
+			gda_column_set_caption (column, (gchar*)spec->caption);
+			gda_column_set_dbms_type (column, (gchar*)spec->dbms_type);
 			gda_column_set_scale (column, spec->scale);
 			gda_column_set_g_type (column, spec->gdatype);
 			gda_column_set_allow_null (column, spec->nullok);
 			gda_column_set_primary_key (column, spec->pkey);
 			gda_column_set_unique_key (column, spec->unique);
-			gda_column_set_table (column, spec->table);
-			gda_column_set_references (column, spec->ref);
+			gda_column_set_table (column, (gchar*)spec->table);
+			gda_column_set_references (column, (gchar*)spec->ref);
 			
 			list = g_slist_next (list);
 			pos++;
@@ -1423,7 +1450,7 @@ init_xml_import (GdaDataModelImport *model)
 
 		/* move to find the <gda_array_data> tag */
 		name = (ret > 0) ? xmlTextReaderConstName (reader) : NULL;
-		if (!name || strcmp (name, "gda_array_data")) {
+		if (!name || strcmp ((gchar*)name, "gda_array_data")) {
 			gchar *str;
 
 			if (name)
@@ -1493,7 +1520,7 @@ xml_fetch_next_row (GdaDataModelImport *model)
 
 	/* we must now have a <gda_array_row> tag */
 	name = xmlTextReaderConstName (reader);
-	if (!name || strcmp (name, "gda_array_row")) {
+	if (!name || strcmp ((gchar*)name, "gda_array_row")) {
 		gchar *str;
 
 		str = g_strdup_printf (_("Expected <gda_array_row> in <gda_array_data>, got <%s>"), name);
@@ -1507,11 +1534,11 @@ xml_fetch_next_row (GdaDataModelImport *model)
 	/* compute values */
 	ret = xml_fetch_next_xml_node (reader);
 	name = (ret > 0) ? xmlTextReaderConstName (reader) : NULL;
-	while (name && !strcmp (name, "gda_value")) {
+	while (name && !strcmp ((gchar*)name, "gda_value")) {
 		/* ignore this <gda_value> if the "lang" is there and is not the user locale */
 		xmlChar *this_lang;
-		this_lang = xmlTextReaderGetAttribute (reader, "xml:lang");
-		if (this_lang && strncmp (this_lang, lang, strlen (this_lang))) {
+		this_lang = xmlTextReaderGetAttribute (reader, (xmlChar*)"xml:lang");
+		if (this_lang && strncmp ((gchar*)this_lang, (gchar*)lang, strlen ((gchar*)this_lang))) {
 			xmlFree (this_lang);
 			ret = xml_fetch_next_xml_node (reader);
 			name = (ret > 0) ? xmlTextReaderConstName (reader) : NULL;
@@ -1596,7 +1623,7 @@ init_node_import (GdaDataModelImport *model)
 	if (!node)
 		return;
 
-	if (strcmp (node->name, "gda_array")) {
+	if (strcmp ((gchar*)node->name, "gda_array")) {
 		gchar *str;
 
 		str = g_strdup_printf (_("Expected <gda_array> node but got <%s>"), node->name);
@@ -1610,21 +1637,21 @@ init_node_import (GdaDataModelImport *model)
 	for (cur = node->children; cur; cur=cur->next) {
 		if (xmlNodeIsText (cur))
 			continue;
-		if (!strcmp (cur->name, "gda_array_field")) {
+		if (!strcmp ((gchar*)cur->name, "gda_array_field")) {
 			XmlColumnSpec *spec;
 
 			spec = g_new0 (XmlColumnSpec, 1);
 			fields = g_slist_append (fields, spec);
 			
-			spec->id = xmlGetProp (cur, "id");
-			spec->name = xmlGetProp (cur, "name");
-			spec->title = xmlGetProp (cur, "title");
+			spec->id = xmlGetProp (cur, (xmlChar*)"id");
+			spec->name = xmlGetProp (cur, (xmlChar*)"name");
+			spec->title = xmlGetProp (cur, (xmlChar*)"title");
 			if (!spec->title && spec->name)
-				spec->title = g_strdup (spec->name);
+				spec->title = xmlStrdup (spec->name);
 
-			spec->caption = xmlGetProp (cur, "caption");
-			spec->dbms_type = xmlGetProp (cur, "dbms_type");
-			str = xmlGetProp (cur, "gdatype");
+			spec->caption = xmlGetProp (cur, (xmlChar*)"caption");
+			spec->dbms_type = xmlGetProp (cur, (xmlChar*)"dbms_type");
+			str = (gchar*)xmlGetProp (cur, (xmlChar*)"gdatype");
 			if (str) {
 				spec->gdatype = gda_g_type_from_string (str);
 				xmlFree (str);
@@ -1635,44 +1662,44 @@ init_node_import (GdaDataModelImport *model)
 				node = model->priv->extract.node.node = NULL;
 				return;
 			}
-			str = xmlGetProp (cur, "size");
+			str = (gchar*)xmlGetProp (cur, (xmlChar*)"size");
 			if (str) {
 				spec->size = atoi (str);
 				xmlFree (str);
 			}
-			str = xmlGetProp (cur, "scale");
+			str = (gchar*)xmlGetProp (cur, (xmlChar*)"scale");
 			if (str) {
 				spec->scale = atoi (str);
 				xmlFree (str);
 			}
-			str = xmlGetProp (cur, "pkey");
+			str = (gchar*)xmlGetProp (cur, (xmlChar*)"pkey");
 			if (str) {
 				spec->pkey = ((*str == 't') || (*str == 'T')) ? TRUE : FALSE;
 				xmlFree (str);
 			}
-			str = xmlGetProp (cur, "unique");
+			str = (gchar*)xmlGetProp (cur, (xmlChar*)"unique");
 			if (str) {
 				spec->unique = ((*str == 't') || (*str == 'T')) ? TRUE : FALSE;
 				xmlFree (str);
 			}
-			str = xmlGetProp (cur, "nullok");
+			str = (gchar*)xmlGetProp (cur, (xmlChar*)"nullok");
 			spec->nullok = TRUE;
 			if (str) {
 				spec->nullok = ((*str == 't') || (*str == 'T')) ? TRUE : FALSE;
 				xmlFree (str);
 			}
-			str = xmlGetProp (cur, "auto_increment");
+			str = (gchar*)xmlGetProp (cur, (xmlChar*)"auto_increment");
 			if (str) {
 				spec->autoinc = ((*str == 't') || (*str == 'T')) ? TRUE : FALSE;
 				xmlFree (str);
 			}
-			spec->table = xmlGetProp (cur, "table");
-			spec->ref = xmlGetProp (cur, "ref");
+			spec->table = xmlGetProp (cur, (xmlChar*)"table");
+			spec->ref = xmlGetProp (cur, (xmlChar*)"ref");
 
 			nbfields ++;
 			continue;
 		}
-		if (!strcmp (cur->name, "gda_array_data"))
+		if (!strcmp ((gchar*)cur->name, "gda_array_data"))
 			break;
 	}
 
@@ -1686,19 +1713,19 @@ init_node_import (GdaDataModelImport *model)
 	/* random access model creation */
 	ramodel = gda_data_model_array_new (nbfields);
 	model->priv->random_access_model = ramodel;
-	str = xmlGetProp (node, "id");
+	str = (gchar*)xmlGetProp (node, (xmlChar*)"id");
 	if (str) {
 		/* FIXME: use str+2 only if str is like "DA%d", otherwise simply use str */
 		gda_object_set_id (GDA_OBJECT (model), str+2);
 		xmlFree (str);
 	}
-	str = xmlGetProp (node, "name");
+	str = (gchar*)xmlGetProp (node, (xmlChar*)"name");
 	if (str) {
 		gda_object_set_name (GDA_OBJECT (model), str);
 		xmlFree (str);
 	}
 
-	str = xmlGetProp (node, "descr");
+	str = (gchar*)xmlGetProp (node, (xmlChar*)"descr");
 	if (str) {
 		gda_object_set_description (GDA_OBJECT (model), str);
 		xmlFree (str);
@@ -1713,18 +1740,18 @@ init_node_import (GdaDataModelImport *model)
 		spec = (XmlColumnSpec *)(list->data);
 		column = gda_data_model_describe_column (ramodel, pos);
 		g_object_set (G_OBJECT (column), "id", spec->id, NULL);
-		gda_column_set_title (column, spec->title);
-		gda_column_set_name (column, spec->name);
+		gda_column_set_title (column, (gchar*)spec->title);
+		gda_column_set_name (column, (gchar*)spec->name);
 		gda_column_set_defined_size (column, spec->size);
-		gda_column_set_caption (column, spec->caption);
-		gda_column_set_dbms_type (column, spec->dbms_type);
+		gda_column_set_caption (column, (gchar*)spec->caption);
+		gda_column_set_dbms_type (column, (gchar*)spec->dbms_type);
 		gda_column_set_scale (column, spec->scale);
 		gda_column_set_g_type (column, spec->gdatype);
 		gda_column_set_allow_null (column, spec->nullok);
 		gda_column_set_primary_key (column, spec->pkey);
 		gda_column_set_unique_key (column, spec->unique);
-		gda_column_set_table (column, spec->table);
-		gda_column_set_references (column, spec->ref);
+		gda_column_set_table (column, (gchar*)spec->table);
+		gda_column_set_references (column, (gchar*)spec->ref);
 
 		model->priv->columns = g_slist_prepend (model->priv->columns, gda_column_copy (column));
 
@@ -1836,11 +1863,11 @@ gda_data_model_import_describe_column (GdaDataModel *model, gint col)
 		return NULL;
 }
 
-static guint
+static GdaDataModelAccessFlags
 gda_data_model_import_get_access_flags (GdaDataModel *model)
 {
 	GdaDataModelImport *imodel;
-	guint flags = GDA_DATA_MODEL_ACCESS_CURSOR_FORWARD;
+	GdaDataModelAccessFlags flags = GDA_DATA_MODEL_ACCESS_CURSOR_FORWARD;
 
 	g_return_val_if_fail (GDA_IS_DATA_MODEL_IMPORT (model), 0);
 	imodel = GDA_DATA_MODEL_IMPORT (model);
@@ -1871,10 +1898,10 @@ gda_data_model_import_get_value_at (GdaDataModel *model, gint col, gint row)
 		return NULL;
 }
 
-static guint
+static GdaValueAttribute
 gda_data_model_import_get_attributes_at (GdaDataModel *model, gint col, gint row)
 {
-	guint flags = 0;
+	GdaValueAttribute flags = 0;
 	GdaDataModelImport *imodel;
 
 	g_return_val_if_fail (GDA_IS_DATA_MODEL_IMPORT (model), 0);
