@@ -38,6 +38,7 @@ static void gda_dict_database_init (GdaDictDatabase * srv);
 static void gda_dict_database_dispose (GObject   * object);
 static void gda_dict_database_finalize (GObject   * object);
 
+#if 0 /* This object does not have any properties. */
 static void gda_dict_database_set_property (GObject *object,
 				    guint param_id,
 				    const GValue *value,
@@ -46,6 +47,7 @@ static void gda_dict_database_get_property (GObject *object,
 				    guint param_id,
 				    GValue *value,
 				    GParamSpec *pspec);
+#endif
 
 static void        gda_dict_database_xml_storage_init (GdaXmlStorageIface *iface);
 static gchar      *gda_dict_database_get_xml_id (GdaXmlStorage *iface);
@@ -91,11 +93,13 @@ enum
 static gint gda_dict_database_signals[LAST_SIGNAL] = { 0, 0, 0, 0, 0, 0, 0, 0, 0 };
 
 /* properties */
+#if 0 /* This object does not have any properties. */
 enum
 {
 	PROP_0,
 	PROP
 };
+#endif
 
 
 /* private structure */
@@ -185,72 +189,75 @@ gda_dict_database_class_init (GdaDictDatabaseClass * class)
                               G_SIGNAL_RUN_FIRST,
                               G_STRUCT_OFFSET (GdaDictDatabaseClass, table_added),
                               NULL, NULL,
-                              gda_marshal_VOID__POINTER,
-                              G_TYPE_NONE, 1, G_TYPE_POINTER);
+                              gda_marshal_VOID__OBJECT,
+                              G_TYPE_NONE, 1, GDA_TYPE_DICT_TABLE);
 	gda_dict_database_signals[TABLE_REMOVED] =
                 g_signal_new ("table_removed",
                               G_TYPE_FROM_CLASS (object_class),
                               G_SIGNAL_RUN_FIRST,
                               G_STRUCT_OFFSET (GdaDictDatabaseClass, table_removed),
                               NULL, NULL,
-                              gda_marshal_VOID__POINTER,
-                              G_TYPE_NONE, 1, G_TYPE_POINTER);
+                              gda_marshal_VOID__OBJECT,
+                              G_TYPE_NONE, 1, GDA_TYPE_DICT_TABLE);
 	gda_dict_database_signals[TABLE_UPDATED] =
                 g_signal_new ("table_updated",
                               G_TYPE_FROM_CLASS (object_class),
                               G_SIGNAL_RUN_FIRST,
                               G_STRUCT_OFFSET (GdaDictDatabaseClass, table_updated),
                               NULL, NULL,
-                              gda_marshal_VOID__POINTER,
-                              G_TYPE_NONE, 1, G_TYPE_POINTER);
+                              gda_marshal_VOID__OBJECT,
+                              G_TYPE_NONE, 1, GDA_TYPE_DICT_TABLE);
+
         gda_dict_database_signals[FIELD_ADDED] =
                 g_signal_new ("field_added",
                               G_TYPE_FROM_CLASS (object_class),
                               G_SIGNAL_RUN_FIRST,
                               G_STRUCT_OFFSET (GdaDictDatabaseClass, field_added),
                               NULL, NULL,
-                              gda_marshal_VOID__POINTER,
-                              G_TYPE_NONE, 1, G_TYPE_POINTER);
+                              gda_marshal_VOID__OBJECT,
+                              G_TYPE_NONE, 1, GDA_TYPE_DICT_FIELD);
         gda_dict_database_signals[FIELD_REMOVED] =
                 g_signal_new ("field_removed",
                               G_TYPE_FROM_CLASS (object_class),
                               G_SIGNAL_RUN_FIRST,
                               G_STRUCT_OFFSET (GdaDictDatabaseClass, field_removed),
                               NULL, NULL,
-                              gda_marshal_VOID__POINTER,
-                              G_TYPE_NONE, 1, G_TYPE_POINTER);
+                              gda_marshal_VOID__OBJECT,
+                              G_TYPE_NONE, 1, GDA_TYPE_DICT_FIELD);
         gda_dict_database_signals[FIELD_UPDATED] =
                 g_signal_new ("field_updated",
                               G_TYPE_FROM_CLASS (object_class),
                               G_SIGNAL_RUN_FIRST,
                               G_STRUCT_OFFSET (GdaDictDatabaseClass, field_updated),
                               NULL, NULL,
-                              gda_marshal_VOID__POINTER,
-                              G_TYPE_NONE, 1, G_TYPE_POINTER);
+                              gda_marshal_VOID__OBJECT,
+                              G_TYPE_NONE, 1, GDA_TYPE_DICT_FIELD);
+
         gda_dict_database_signals[CONSTRAINT_ADDED] =
                 g_signal_new ("constraint_added",
                               G_TYPE_FROM_CLASS (object_class),
                               G_SIGNAL_RUN_FIRST,
                               G_STRUCT_OFFSET (GdaDictDatabaseClass, constraint_added),
                               NULL, NULL,
-                              gda_marshal_VOID__POINTER,
-                              G_TYPE_NONE, 1, G_TYPE_POINTER);
+                              gda_marshal_VOID__OBJECT,
+                              G_TYPE_NONE, 1, GDA_TYPE_DICT_CONSTRAINT);
         gda_dict_database_signals[CONSTRAINT_REMOVED] =
                 g_signal_new ("constraint_removed",
                               G_TYPE_FROM_CLASS (object_class),
                               G_SIGNAL_RUN_FIRST,
                               G_STRUCT_OFFSET (GdaDictDatabaseClass, constraint_removed),
                               NULL, NULL,
-                              gda_marshal_VOID__POINTER,
-                              G_TYPE_NONE, 1, G_TYPE_POINTER);
+                              gda_marshal_VOID__OBJECT,
+                              G_TYPE_NONE, 1, GDA_TYPE_DICT_CONSTRAINT);
         gda_dict_database_signals[CONSTRAINT_UPDATED] =
                 g_signal_new ("constraint_updated",
                               G_TYPE_FROM_CLASS (object_class),
                               G_SIGNAL_RUN_FIRST,
                               G_STRUCT_OFFSET (GdaDictDatabaseClass, constraint_updated),
                               NULL, NULL,
-                              gda_marshal_VOID__POINTER,
-                              G_TYPE_NONE, 1, G_TYPE_POINTER);
+                              gda_marshal_VOID__OBJECT,
+                              G_TYPE_NONE, 1, GDA_TYPE_DICT_CONSTRAINT);
+
 	gda_dict_database_signals[DATA_UPDATE_STARTED] =
                 g_signal_new ("data_update_started",
                               G_TYPE_FROM_CLASS (object_class),
@@ -265,8 +272,8 @@ gda_dict_database_class_init (GdaDictDatabaseClass * class)
                               G_SIGNAL_RUN_FIRST,
                               G_STRUCT_OFFSET (GdaDictDatabaseClass, update_progress),
                               NULL, NULL,
-                              gda_marshal_VOID__POINTER_UINT_UINT,
-                              G_TYPE_NONE, 3, G_TYPE_POINTER, G_TYPE_UINT, G_TYPE_UINT);
+                              gda_marshal_VOID__STRING_UINT_UINT,
+                              G_TYPE_NONE, 3, G_TYPE_STRING, G_TYPE_UINT, G_TYPE_UINT);
 	gda_dict_database_signals[DATA_UPDATE_FINISHED] =
                 g_signal_new ("data_update_finished",
                               G_TYPE_FROM_CLASS (object_class),
@@ -292,6 +299,7 @@ gda_dict_database_class_init (GdaDictDatabaseClass * class)
 	object_class->dispose = gda_dict_database_dispose;
 	object_class->finalize = gda_dict_database_finalize;
 
+        #if 0 /* This object does not have any properties.
 	/* Properties */
 	object_class->set_property = gda_dict_database_set_property;
 	object_class->get_property = gda_dict_database_get_property;
@@ -302,6 +310,7 @@ gda_dict_database_class_init (GdaDictDatabaseClass * class)
          */
 	g_object_class_install_property (object_class, PROP,
 					 g_param_spec_pointer ("prop", NULL, NULL, (G_PARAM_READABLE | G_PARAM_WRITABLE)));
+        #endif
 
 	/* virtual functions */
 #ifdef GDA_DEBUG
@@ -410,7 +419,7 @@ gda_dict_database_finalize (GObject *object)
 	parent_class->finalize (object);
 }
 
-
+#if 0 /* This object does not have any properties. */
 static void 
 gda_dict_database_set_property (GObject *object,
 			guint param_id,
@@ -430,6 +439,7 @@ gda_dict_database_set_property (GObject *object,
 		}
 	}
 }
+
 static void
 gda_dict_database_get_property (GObject *object,
 			guint param_id,
@@ -448,6 +458,7 @@ gda_dict_database_get_property (GObject *object,
 		}	
 	}
 }
+#endif
 
 
 /* GdaXmlStorage interface implementation */
@@ -473,10 +484,10 @@ gda_dict_database_save_to_xml (GdaXmlStorage *iface, GError **error)
 	db = GDA_DICT_DATABASE (iface);
 
 	/* main node */
-        toptree = xmlNewNode (NULL, "gda_dict_database");
+        toptree = xmlNewNode (NULL, (xmlChar*)"gda_dict_database");
 	
 	/* Tables */
-	tree = xmlNewChild (toptree, NULL, "gda_dict_tables", NULL);
+	tree = xmlNewChild (toptree, NULL, (xmlChar*)"gda_dict_tables", NULL);
 	list = db->priv->tables;
 	while (list) {
 		xmlNodePtr table;
@@ -494,7 +505,7 @@ gda_dict_database_save_to_xml (GdaXmlStorage *iface, GError **error)
 	}
 
 	/* Constraints */
-	tree = xmlNewChild (toptree, NULL, "gda_dict_constraints", NULL);
+	tree = xmlNewChild (toptree, NULL, (xmlChar*)"gda_dict_constraints", NULL);
 	list = db->priv->constraints;
 	while (list) {
 		xmlNodePtr cstr;
@@ -535,7 +546,7 @@ gda_dict_database_load_from_xml (GdaXmlStorage *iface, xmlNodePtr node, GError *
 			     _("Database already contains data"));
 		return FALSE;
 	}
-	if (strcmp (node->name, "gda_dict_database")) {
+	if (strcmp ((gchar*)node->name, "gda_dict_database")) {
 		g_set_error (error,
 			     GDA_DICT_DATABASE_ERROR,
 			     GDA_DICT_DATABASE_XML_LOAD_ERROR,
@@ -547,7 +558,7 @@ gda_dict_database_load_from_xml (GdaXmlStorage *iface, xmlNodePtr node, GError *
 	while (subnode) {
 		gboolean done = FALSE;
 
-		if (!strcmp (subnode->name, "gda_dict_tables")) {
+		if (!strcmp ((gchar*)subnode->name, "gda_dict_tables")) {
 			if (!gda_dict_database_load_from_xml_tables (iface, subnode, error)) {
 				db->priv->xml_loading = FALSE;
 				return FALSE;
@@ -556,7 +567,7 @@ gda_dict_database_load_from_xml (GdaXmlStorage *iface, xmlNodePtr node, GError *
 			done = TRUE;
 		}
 
-		if (!done && !strcmp (subnode->name, "gda_dict_constraints")) {
+		if (!done && !strcmp ((gchar*)subnode->name, "gda_dict_constraints")) {
 			if (!gda_dict_database_load_from_xml_constraints (iface, subnode, error)) {
 				db->priv->xml_loading = FALSE;
 				return FALSE;
@@ -580,7 +591,7 @@ gda_dict_database_load_from_xml_tables (GdaXmlStorage *iface, xmlNodePtr node, G
 
 	while (subnode && allok) {
 		if (! xmlNodeIsText (subnode)) {
-			if (!strcmp (subnode->name, "gda_dict_table")) {
+			if (!strcmp ((gchar*)subnode->name, "gda_dict_table")) {
 				GdaDictTable *table;
 				
 				table = GDA_DICT_TABLE (gda_dict_table_new (gda_object_get_dict (GDA_OBJECT (iface))));
@@ -613,7 +624,7 @@ gda_dict_database_load_from_xml_constraints (GdaXmlStorage *iface, xmlNodePtr no
 
 	while (subnode && allok) {
 		if (! xmlNodeIsText (subnode)) {
-			if (!strcmp (subnode->name, "gda_dict_constraint")) {
+			if (!strcmp ((gchar*)subnode->name, "gda_dict_constraint")) {
 				GdaDictConstraint *cstr;
 				
 				cstr = GDA_DICT_CONSTRAINT (gda_dict_constraint_new_with_db (GDA_DICT_DATABASE (iface)));
