@@ -55,12 +55,12 @@ static gboolean    gda_query_field_all_load_from_xml (GdaXmlStorage *iface, xmlN
 /* Field interface */
 static void              gda_query_field_all_field_init      (GdaEntityFieldIface *iface);
 static GdaEntity         *gda_query_field_all_get_entity      (GdaEntityField *iface);
-static GdaDictType *gda_query_field_all_get_data_type   (GdaEntityField *iface);
+static GdaDictType *gda_query_field_all_get_dict_type   (GdaEntityField *iface);
 
 /* Renderer interface */
 static void            gda_query_field_all_renderer_init      (GdaRendererIface *iface);
 static gchar          *gda_query_field_all_render_as_sql   (GdaRenderer *iface, GdaParameterList *context, 
-							    GSList **out_params_used, guint options, GError **error);
+							    GSList **out_params_used, GdaRendererOptions options, GError **error);
 static gchar          *gda_query_field_all_render_as_str   (GdaRenderer *iface, GdaParameterList *context);
 
 /* Referer interface */
@@ -180,7 +180,7 @@ static void
 gda_query_field_all_field_init (GdaEntityFieldIface *iface)
 {
 	iface->get_entity = gda_query_field_all_get_entity;
-	iface->get_data_type = gda_query_field_all_get_data_type;
+	iface->get_dict_type = gda_query_field_all_get_dict_type;
 }
 
 static void
@@ -546,7 +546,7 @@ gda_query_field_all_get_entity (GdaEntityField *iface)
 }
 
 static GdaDictType *
-gda_query_field_all_get_data_type (GdaEntityField *iface)
+gda_query_field_all_get_dict_type (GdaEntityField *iface)
 {
 	g_return_val_if_fail (iface && GDA_IS_QUERY_FIELD_ALL (iface), NULL);
 	g_return_val_if_fail (GDA_QUERY_FIELD_ALL (iface)->priv, NULL);
@@ -691,7 +691,7 @@ gda_query_field_all_load_from_xml (GdaXmlStorage *iface, xmlNodePtr node, GError
 
 static gchar *
 gda_query_field_all_render_as_sql (GdaRenderer *iface, GdaParameterList *context, 
-				   GSList **out_params_used, guint options, GError **error)
+				   GSList **out_params_used, GdaRendererOptions options, GError **error)
 {
 	gchar *str = NULL;
 	GdaObject *base;
