@@ -76,7 +76,8 @@ typedef enum
 	GDA_DELIMITER_PARAM_DESCR,
 	GDA_DELIMITER_PARAM_TYPE,
 	GDA_DELIMITER_PARAM_ISPARAM,
-	GDA_DELIMITER_PARAM_NULLOK
+	GDA_DELIMITER_PARAM_NULLOK,
+	GDA_DELIMITER_PARAM_DEFAULT
 } GdaDelimiterParamSpecType;
 
 /*
