@@ -1,5 +1,5 @@
 /* GDA Postgres Provider
- * Copyright (C) 1998-2002 The GNOME Foundation
+ * Copyright (C) 1998 - 2007 The GNOME Foundation
  *
  * AUTHORS:
  *         Vivien Malerba <malerba@gnome-db.org>
@@ -21,16 +21,12 @@
  * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-#if !defined(__gda_postgres_h__)
-#  define __gda_postgres_h__
-
-#if defined(HAVE_CONFIG_H)
-#endif
+#ifndef __GDA_POSTGRES_H__
+#define __GDA_POSTGRES_H__
 
 #include <glib/gmacros.h>
 #include <glib/gi18n-lib.h>
 #include <libgda/gda-server-provider.h>
-#include <libgda/gda-blob.h>
 #include "gda-postgres-provider.h"
 #include "gda-postgres-recordset.h"
 
@@ -42,7 +38,7 @@ G_BEGIN_DECLS
  * Utility functions
  */
 
-GdaConnectionEvent *gda_postgres_make_error (PGconn *pconn, PGresult *pg_res);
+GdaConnectionEvent *gda_postgres_make_error (GdaConnection *cnc, PGconn *pconn, PGresult *pg_res);
 void gda_postgres_set_value (GdaConnection *cnc,
 			     GValue *value, 
 			     GType type, 
@@ -60,7 +56,7 @@ GType gda_postgres_type_name_to_gda (GHashTable *h_table,
 
 const gchar *gda_data_type_to_string (GType type);
 gchar *gda_postgres_value_to_sql_string (GValue *value);
-
+gboolean gda_postgres_check_transaction_started (GdaConnection *cnc);
 G_END_DECLS
 
 #endif
